// RadioActive Copyright (C) 1999 RDI Gerg <cactus@cactus.rulez.org>
// 
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License version 2
// (included in the RadioActive distribution in doc/GPL) as published by
// the Free Software Foundation.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

//$Id: radioactive.h,v 1.24 2001/11/06 17:45:38 cactus Exp $ -*- c++ -*-
#ifndef RADIO_h
#define RADIO_h

#include "config.h"

#define PROGNAME "RadioActive"
#define RADIO_RCDIR ".radioactive"
#define DEVFILE "/dev/radio0"

#define RADIO_VOL_MIN 0
#define RADIO_VOL_MAX 10
#define RADIO_VOL_DEF 8

#define RADIO_APPLET_TIMEOUT      1000 // Timeout for holding down the
                                       // mouse button on the applet buttons
#define RADIO_TUNER_TIMEOUT       1000
#define RADIO_TUNER_TIMEOUT_FINE  100

// Stupid error in the stock libgnome/libgnome.h
#include <libgnome/libgnome.h>

#include <string>
#include <vector>

typedef std::pair<float, std::string> StationData;
typedef std::vector<StationData>      SpeedButtonData;

#endif
